@@ -49,7 +49,7 @@ KAFKA_BOOTSTRAP_SERVERS = ['192.xx.xx.202:9092']
 ALWAYS_ADD_KAFKA_HANDLER_IN_TEST_ENVIRONENT = True
 
 
-class app_config:  # 由于日志引用导入了app.config模块，此处模拟模块级的配置，实际代码不是这样。
+class app_config:  # 由于日志引用导入了app.config as app_config，此处模拟模块级的配置，实际代码不是这样。
     env = 'production'
     connect_url = 'mongo://xxx'  # mongo连接
 
@@ -943,11 +943,11 @@ class LogManager(object):
                                          log_filename=None,
                                          log_file_size=100, mongo_url=None, is_add_elastic_handler=False, is_add_kafka_handler=False,
                                          ding_talk_token=DING_TALK_TOKEN, ding_talk_time_interval=60,
-                                         formatter_template=5, mailhost: tuple = EMAIL_HOST,  # ('smtpdm.aliyun.com', 465), # 公司邮箱有频率限制影响业务
-                                         fromaddr: str = EMAIL_FROMADDR,  # 'matafyhotel-techl@matafy.com',
+                                         formatter_template=5, mailhost: tuple = EMAIL_HOST,
+                                         fromaddr: str = EMAIL_FROMADDR,
                                          toaddrs: tuple = EMAIL_TOADDRS,
                                          subject: str = '马踏飞燕日志报警测试',
-                                         credentials: tuple = EMAIL_CREDENTIALS,  # ('matafyhotel-techl@matafy.com', 'DDMkXzmlZtlNXB81YrYH'),
+                                         credentials: tuple = EMAIL_CREDENTIALS,
                                          secure=None, timeout=5.0, is_use_ssl=True, mail_time_interval=60):
 
         if log_filename is None:
@@ -1323,6 +1323,9 @@ class _Test(unittest.TestCase):
         # logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(mongo_url=app_config.connect_url, formatter_template=5)
         logging.error('xxxx')
         logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(formatter_template=5)
+        logger.addHandler(ColorHandler())    # 由于打了强大的猴子补丁，无惧反复添加同种handler。
+        logger.addHandler(ColorHandler())
+        logger.addHandler(ColorHandler())
         for i in range(1000000):
             time.sleep(0.1)
             logger.debug('一个debug级别的日志。' * 5)
